<!--工单信息-->
<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="query" :inline="true" label-suffix="：">
        <el-form-item label="巡检计划名称">
          <el-input
            :clearable="true"
            placeholder="请输入巡检计划名称"
            v-model="query.inspectionPlanName"
          />
        </el-form-item>
        <el-form-item label="巡查计划时间" prop="inspectionPlanTime">
          <el-date-picker
            clearable
            type="date"
            value-format="yyyy-MM-dd"
            style="width:100%"
            placeholder="请选择巡查计划时间"
            v-model="query.inspectionPlanTime"
          ></el-date-picker>
        </el-form-item>
        <el-form-item label="巡检类型">
          <el-select
            placeholder="请选择巡检类型"
            v-model="query.inspectionType"
            clearable
          >
            <el-option
              v-for="item in inspectionTypeOpt"
              :key="item.value"
              :label="item.name"
              :value="item.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" @click="handleSearch">
            搜索
          </el-button>
          <el-button icon="el-icon-refresh" @click="handleReset">
            重置
          </el-button>
        </el-form-item>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">

      </div>
      <el-table
        border
        size="mini"
        v-loading="loading"
        ref="multipleSelection"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @selection-change="handleSelectionChange"
        row-key="id"
      >
        <el-table-column type="index" width="70" label="序号" align="center">
        </el-table-column>
        <el-table-column
          prop="inspectionPlanName"
          show-overflow-tooltip
          align="center"
          label="巡查计划名称"
          min-width="200"
        />
        <el-table-column
          prop="inspectionPlanTime"
          show-overflow-tooltip
          align="center"
          label="巡查计划时间"
          min-width="100"
        />
        <el-table-column
          prop="inspectionType"
          show-overflow-tooltip
          align="center"
          label="巡检类型"
          :formatter="({inspectionType}) => dictionaryEscape(inspectionTypeOpt,inspectionType)"
        />
        <el-table-column
          prop="total"
          show-overflow-tooltip
          align="center"
          label="设备总数"
        />
        <el-table-column
          prop="pendingOrders"
          show-overflow-tooltip
          align="center"
          label="待维修数"
        />
        <el-table-column
          prop="transferOrder"
          show-overflow-tooltip
          align="center"
          label="申请转单数"
        />
        <el-table-column
          prop="application"
          show-overflow-tooltip
          align="center"
          label="延期申请数"
        />
        <el-table-column
          prop="receivingOrders"
          show-overflow-tooltip
          align="center"
          label="维修中数"
        />
        <el-table-column
          prop="finishMaintenance"
          show-overflow-tooltip
          align="center"
          label="已维修数"
        />
        <el-table-column
          prop="finished"
          show-overflow-tooltip
          align="center"
          label="已完成数"
        />
        -
      </el-table>
      <el-pagination
        align="right"
        background
        class="bbsl-pagination"
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParams.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParams.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="queryParams.total"
      ></el-pagination>
    </div>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import {tableData} from '@/api/device/workOrderAnalysis'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'

export default {
  name: 'RoutineInspection',
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      tableData: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      query: {
        inspectionPlanName: '',
        inspectionPlanTime: '',
        inspectionType: ''
      },
      sorter: [],
      inspectionTypeOpt: dictUtils.getDictItemsFromCache('xjlx') || []
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = []
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          const value = item[i.property]
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return {operation: 'EQUAL', group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
  },
  methods: {
    dictionaryEscape,

    // 获取list
    async loadData() {
      this.loading = true
      const {rows, total} = (await tableData(this.computedQuery, this.query))?.value || {}
      this.tableData = rows || []
      this.queryParams.total = total || 0
      this.loading = false
    },

    // 顶部搜索
    handleSearch() {
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.query = this.$options.data().query
      this.loadData()
    },


    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.loadData()
    }

  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
